% This Matlab function is called by MT3D_Viewer to plot data and results of the 3D MT 
% inversion (e.g. input data and model responses).
% M. Gharibi  Quantec Geoscience Ltd.
% Sep. 2009


function [in]=MT3D_PlotImpedance(in);

% check if data exists; crash protection!
if isempty(in), return; end;

    fig1=figure(1);
    set(fig1,'Color',[1,1,0.5]);
    scrsz = get(0,'ScreenSize');
    set(fig1,'Position',[0 0 scrsz(3) scrsz(4)/1.1]);
    set(fig1,'NumberTitle','off','Name','MT3D Data and Model Response Viewer'); 

%Check if Interactive Map callback requested
if in{1}.map == -1
    subplot(2,2,1,'replace');

%  Plot RMS errors if available
   if in{1}.imp_err ~= 0,
       dx=(max(in{1}.y_err)-min(in{1}.y_err))/100;
       dy=(max(in{1}.x_err)-min(in{1}.x_err))/100;
       [x_c,y_c]=meshgrid(min(in{1}.y_err):dx:max(in{1}.y_err),...
           min(in{1}.x_err):dy:max(in{1}.x_err));
       [site_err_c]=griddata(in{1}.y_err,in{1}.x_err,in{1}.site_err,x_c,y_c,'linear');
       [err_c,h_c]=contour(x_c,y_c,site_err_c);
        hold on;
    end
 
 % Plot site locations   
    set(plot(in{1}.y_data,in{1}.x_data),'Marker','o','MarkerSize',3,...
    'MarkerEdgeColor','r','MarkerFaceColor','r','LineStyle','none');
    axis equal;
    if in{1}.imp_err ~= 0,
       title('Location Map and RMS Error Contour; Click to Choose a Site to Display','FontWeight','bold'); 
    else
       title('Location Map; Click to Choose','FontWeight','bold');
    end
    xlabel('Grid Easting (m)'); ylabel('Grid Northing (m)'); 
    h_offset=(max(in{1}.y_data)-min(in{1}.y_data))/80;
    set(text(in{1}.y_data+h_offset,in{1}.x_data,...
    num2str([1:length(in{1}.x_data)]','%4d')),'FontSize',8);
    grid off;    hold off;

% get location
    [ew_tmpo,ns_tmpo]=ginput(1);

% assign the closest site
    for kk=1:1:max(in{1}.para_data(1))
        min_tmpo(kk)=sqrt((in{1}.x_data(kk)-ns_tmpo)^2+(in{1}.y_data(kk)-ew_tmpo)^2);
    end
    [minmin,in{1}.i]=min(min_tmpo);

    in{1}.map = 1;
end
    
% check for site index out of range
    if in{1}.i > in{1}.para_data(1)
       in{1}.i = in{1}.i - in{1}.para_data(1); 
   elseif in{1}.i < 1
       in{1}.i = in{1}.i + in{1}.para_data(1);
   else
   end

 %% Start plotting
   % plot Zxy
    subplot(2,2,2,'replace');
    plot(log10(in{1}.freq_data), in{1}.z_data(:,1,in{1}.i),'go-',...
        'MarkerEdgeColor','g','MarkerFaceColor','g','MarkerSize',5,'LineWidth',2);
    hold on;
    plot(log10(in{1}.freq_data), in{1}.z_data(:,2,in{1}.i),'rs-',...
        'MarkerEdgeColor','r','MarkerFaceColor','r','MarkerSize',4,'LineWidth',2);
    set(gca,'XDir','reverse');
    ylabel('Impedance (Ohm)');
    xlabel('LOG Frequency (Hz)');
    title('Zxy','FontSize',15);
    grid;
    plot(log10(in{1}.freq_resp), in{1}.z_resp(:,1,in{1}.i),'ko-',...
        'MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',5,'LineWidth',2);
    plot(log10(in{1}.freq_resp), in{1}.z_resp(:,2,in{1}.i),'ys-',...
        'MarkerEdgeColor','y','MarkerFaceColor','y','MarkerSize',4,'LineWidth',2);
    legend('Input Zxy Real','Input Zxy Imag','Resp Zxy Real','Resp Zxy Imag'); 
    hold off;
 
% Plot Zyx
    subplot(2,2,3,'replace');
    plot(log10(in{1}.freq_data), in{1}.z_data(:,3,in{1}.i),'go-',...
        'MarkerEdgeColor','g','MarkerFaceColor','g','MarkerSize',5,'LineWidth',2);
    hold on;
    plot(log10(in{1}.freq_data), in{1}.z_data(:,4,in{1}.i),'rs-',...
        'MarkerEdgeColor','r','MarkerFaceColor','r','MarkerSize',4,'LineWidth',2);
    set(gca,'XDir','reverse');
    ylabel('Impedance (Ohm)');
    xlabel('LOG Frequency (Hz)');
    title('Zyx','FontSize',15);
    grid;
    plot(log10(in{1}.freq_resp), in{1}.z_resp(:,3,in{1}.i),'ko-',...
        'MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',5,'LineWidth',2);
    plot(log10(in{1}.freq_resp), in{1}.z_resp(:,4,in{1}.i),'ys-',...
        'MarkerEdgeColor','y','MarkerFaceColor','y','MarkerSize',4,'LineWidth',2);
    legend('Input Zyx Real','Input Zyx Imag','Resp Zyx Real','Resp Zyx Imag'); 
%    legend boxoff; 
    hold off;
    
% Plot info 
    subplot(2,2,1,'replace');
    axis off;
    if in{1}.imp_SiteName ~= 0,
        string1=['Survey Site Name:  ' num2str(in{1}.SiteName(in{1}.i,5)) ];
    else    
        string1=['Grid Site # ' num2str(in{1}.i) ' of ' num2str(max(in{1}.para_data(1)))];
    end
    text(0,1,string1,'FontSize',20,'FontWeight','bold','color','b');
    
    if in{1}.imp_SiteName ~= 0,
    else
       string2=['Grid Northing: ' num2str(in{1}.x_data(in{1}.i))];
       text(0,0.8,string2,'FontSize',12,'FontWeight','bold');
       string3=['Grid Easting: ' num2str(in{1}.y_data(in{1}.i))];
       text(0,0.7,string3,'FontSize',12,'FontWeight','bold');
    end
    text(0,0.5,['Data Filename:  ', in{1}.filename_data'],'Interpreter','none','FontWeight','bold');
    text(0,0.4,['Response Filename:  ', in{1}.filename_resp'],'Interpreter','none','FontWeight','bold');
    if in{1}.imp_err ~= 0,
        text(0,0.2,['Site RMS Error:  ', num2str(in{1}.site_err(in{1}.i))],'FontWeight','bold','color','red');
        text(0,0.1,['Total RMS Error:  ', num2str(in{1}.total_err)],'FontWeight','bold','color','red');
    end
    hold off;
    
% Plot App. Res.    
    subplot(2,2,4,'replace');
    zxy_data=in{1}.z_data(:,1,in{1}.i)+j*in{1}.z_data(:,2,in{1}.i);
    zyx_data=in{1}.z_data(:,3,in{1}.i)+j*in{1}.z_data(:,4,in{1}.i); 
    zxy_resp=in{1}.z_resp(:,1,in{1}.i)+j*in{1}.z_resp(:,2,in{1}.i);
    zyx_resp=in{1}.z_resp(:,3,in{1}.i)+j*in{1}.z_resp(:,4,in{1}.i); 

    mu0=4*pi*10^-7;
    plot(log10(in{1}.freq_data), log10((abs(zxy_data).^2)./(mu0*2*pi*in{1}.freq_data)),'go-',...
        'MarkerEdgeColor','g','MarkerFaceColor','g','MarkerSize',5,'LineWidth',2);
    x_min=floor(log10(min(in{1}.freq_data))); x_max=ceil(log10(max(in{1}.freq_data)));
    axis([x_min x_max -1 5]);
    set(gca,'XDir','reverse');
    hold on;
    ylabel('LOG Resistivity (Ohm-m)');
    xlabel('LOG Frequency (Hz)');
    title('Apparent Resistivity ','FontSize',15);
    grid;
    plot(log10(in{1}.freq_data), log10((abs(zyx_data).^2)./(mu0*2*pi*in{1}.freq_data)),'rs-',...
        'MarkerEdgeColor','r','MarkerFaceColor','r','MarkerSize',4,'LineWidth',2);
    plot(log10(in{1}.freq_resp), log10((abs(zxy_resp).^2)./(mu0*2*pi*in{1}.freq_resp)),'ko-',...
        'MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',5,'LineWidth',2);
    plot(log10(in{1}.freq_resp), log10((abs(zyx_resp).^2)./(mu0*2*pi*in{1}.freq_resp)),'ys-',...
        'MarkerEdgeColor','y','MarkerFaceColor','y','MarkerSize',4,'LineWidth',2);
    legend('Input RhoXY','Input RhoYX','Resp RhoXY','Resp RhoYX');
    hold off;

    in=in;
    in{1}.fig1=fig1;
    in{1}.scrsz=scrsz(:);
    
    varargout = { in };