% This Matlab function is called in by MT3DViewer and reads in two impedance datasets for the 3D MT 
% inversion (e.g. input data and model responses) for comparison.
% M. Gharibi  Quantec Geoscience Ltd.
% Sep. 2009

function [varargout] = MT3D_ReadIn;

clear all;

% Read in impedance data
[imp_data,dir_data]=uigetfile('*_out.data','SELECT INPUT IMPEDANCE DATA FILE'); 
if imp_data == 0, varargout={cell(-1)}; return; end;
filename_data=imp_data;
imp_data=[dir_data '\' imp_data];
[fid1,message]=fopen(imp_data,'rt');
[para_data]=fscanf(fid1,'%i %i %i ',[3,1]);
[ns_data]=fscanf(fid1,'%30s',[2]);
if ns_data(1:2) ~= 'St', disp(['***Error: Wrong format in data file: ', imp_data, '***']); varargout={cell(-1)}; return; end;
[x_data]=fscanf(fid1,'%g',[para_data(1)]);
[ew_data]=fscanf(fid1,'%30s',[2]);
[y_data]=fscanf(fid1,'%g',[para_data(1)]);
for i=1:1:para_data(2);
    [per_data(i,:,:)]=fscanf(fid1,'%30s %g',[2,1]);
    freq_data=1./per_data(:,1,7);
    [z_data(i,:,:)]=fscanf(fid1,'%g %g %g  %g',[4,para_data(1)]);
end
fclose(fid1);

% Read in impedance response
dir_working=pwd;
cd(dir_data);
[imp_resp,dir_resp]=uigetfile('*_out_resp.*','SELECT RESPONSE IMPEDANCE FILE'); 
if imp_resp== 0, varargout={cell(-1)}; return; end;
filename_resp=imp_resp;
[imp_resp]=[dir_resp '\' imp_resp];
[fid2,message]=fopen(imp_resp,'rt');
[para_resp]=fscanf(fid2,'%i %i %i ',[3,1]);
[ns_resp]=fscanf(fid2,'%30s',[2]);
if ns_resp(1:2) ~= 'St', disp(['***Error: Wrong format in response file: ', imp_resp, '***']); varargout={cell(-1)}; return; end;
[x_resp]=fscanf(fid2,'%g',[para_resp(1)]);
[ew_resp]=fscanf(fid2,'%30s',[2]);
[y_resp]=fscanf(fid2,'%g',[para_resp(1)]);
for i=1:1:para_resp(2);
    [per_resp(i,:,:)]=fscanf(fid2,'%30s %g',[2,1]);
    freq_resp=1./per_resp(:,1,7);
    [z_resp(i,:,:)]=fscanf(fid2,'%g %g %g  %g',[4,para_resp(1)]);
end
fclose(fid2);

% Read in errors
[imp_err,dir_err]=uigetfile('*_out.error','SELECT OUTPUT ERROR FILE (optional)'); 
if imp_err ~= 0,
filename_err=imp_err;
[imp_err]=[dir_err '\' imp_err];
[fid3,message]=fopen(imp_err,'rt');
[para_err]=fscanf(fid3,'%i %i %i ',[3,1]);
[ns_err]=fscanf(fid3,'%30s',[2]);
if ns_err(1:2) ~= 'St', disp(['***Error: Wrong format in error file: ', imp_err, '***']); varargout={cell(-1)}; return; end;
[x_err]=fscanf(fid3,'%g',[para_err(1)]);
[ew_err]=fscanf(fid3,'%30s',[2]);
[y_err]=fscanf(fid3,'%g',[para_err(1)]);
for kk=1:1:para_err(2);
    [per_err(kk,:,:)]=fscanf(fid3,'%30s %g',[2,1]);
    freq_err=1./per_err(:,1,7);
    [z_err(kk,:,:)]=fscanf(fid3,'%g %g %g  %g',[4,para_err(1)]);
end
% calculate errors for sites and grid
z_diff(:,:,:)=(z_data(:,:,:)-z_resp(:,:,:))./z_err(:,:,:);
for kk=1:1:para_err(1),
    site_err(kk)=sqrt(sum(sum(z_diff(:,:,kk).^2))/(para_err(2)*para_err(3)));
end
%total_err=sum(site_err)/para_err(1);
total_err=sqrt(sum(site_err.^2)/para_err(1));

fclose(fid3);
else
    disp('Note: RMS error is not displayed!')
end

% Read in true Site Name
[imp_SiteName,dir_SiteName]=uigetfile('*_Sitenames.txt','SELECT Real Site Name FILE (optional)'); 
if imp_SiteName ~= 0,
disp('Note: Survey Site Names are displayed!')
filename_SiteName=imp_SiteName;
[imp_SiteName]=[dir_SiteName '\' imp_SiteName];
[fid4,message]=fopen(imp_SiteName,'rt');
dummy=fscanf(fid4,'%s ',[1,6]);
[SiteName_tmpo, count_tmpo]=fscanf(fid4,'%g %g %g %g %d %d',[6,inf]);
SiteName=SiteName_tmpo';
fclose(fid4);
else
    disp('Note: WS Site Names are displayed!')    
end

cd(dir_working);


%check for comparability
if para_data(3)~=4 
    disp('***Sorry, this version supports Zxy, Zyx displays only!'); varargout={cell(-1)}; return;
elseif para_data~=para_resp
    disp('MSGID',  'Error: # of sites, periods or components do not match!'); varargout={cell(-1)}; 
    para_data
    para_resp
    return;
elseif freq_data ~= freq_resp
    disp('Warning: Frequencies do not match!')
    disp(freq_data)
    disp(freq_resp)
end

in=cell(1,1);

%initiating plot
in{1}.i=1;
in{1}.map=1;

% Data
in{1}.imp_data=imp_data(:);
in{1}.para_data=para_data(:);
in{1}.ns_data=ns_data(:);
in{1}.x_data=x_data(:);
in{1}.ew_data=ew_data(:);
in{1}.y_data=y_data(:);
in{1}.freq_data=freq_data(:);
in{1}.z_data=z_data(:,:,:);
in{1}.filename_data=filename_data(:);

%Response
in{1}.imp_resp=imp_resp(:);
in{1}.para_resp=para_resp(:);
in{1}.ns_resp=ns_resp(:);
in{1}.x_resp=x_resp(:);
in{1}.ew_resp=ew_resp(:);
in{1}.y_resp=y_resp(:);
in{1}.freq_resp=freq_resp(:);
in{1}.z_resp=z_resp(:,:,:);
in{1}.filename_resp=filename_resp(:);

%Error
in{1}.imp_err=imp_err(:);
if imp_err ~= 0,
in{1}.para_err=para_err(:);
in{1}.ns_err=ns_err(:);
in{1}.x_err=x_err(:);
in{1}.ew_err=ew_err(:);
in{1}.y_err=y_err(:);
in{1}.freq_err=freq_err(:);
in{1}.z_err=z_err(:,:,:);
in{1}.site_err=site_err(:);
in{1}.total_err=total_err;
in{1}.filename_err=filename_err(:);
end

%Site Names
in{1}.imp_SiteName=imp_SiteName(:);
if imp_SiteName ~= 0,
in{1}.SiteName=SiteName(:,:);
end


varargout = { in };
