function [ varargout ] = get_Mesh( varargin )
%%
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%
%%
%% 20090723: add Mesh_utm to WS3D

if  nargin == 1 & isstruct( varargin{ 1 } ) & isfield( varargin{ 1 },'utmE') & isfield( varargin{ 1 },'utmN')
    WS3D = varargin{ 1 };
else
    varargout = { -1 }; 
    return;
end


%% GET MAJOR X-direction (X in Geotools)
lineNo=1;
dlgTitle='Input direction for X (+=E)';
prompt={ 'Azimuth of X (deg +E/-W)' };
def = { '0.0' };
answer={};
while  isempty(answer), answer=inputdlg(prompt,dlgTitle,lineNo,def);end
Mesh.Az = str2double( answer(1) );


% compute Rotated  coordinates in 18/19
alp = -Mesh.Az * pi/180;

ROT = [ cos(alp) sin(alp); -sin(alp) cos(alp) ];
tab = ( ROT * [ WS3D.utmE' ; WS3D.utmN' ] )';
WS3D.utmEr = tab(:,1);
WS3D.utmNr = tab(:,2);

dd=( max( WS3D.utmNr ) - min( WS3D.utmNr ) )/50;


%% GET MESH Delta XY
lineNo=1;
dlgTitle='Input Mesh Size';
prompt={ 'Delta Mesh East  (m)' ; 'Delta Mesh North (m)'};
def = { '200' ; '200'};
answer=inputdlg(prompt,dlgTitle,lineNo,def);
Mesh.de = str2double( answer(1) );
Mesh.dn = str2double( answer(2) );


%% PLOT SITES
[ fig ] = plot_Station( WS3D.utmEr , WS3D.utmNr ); hold on
set(gca,'xgrid','on','ygrid','on');
xtmp = get(gca,'xlim'); xsize = (xtmp(2)-xtmp(1))*0.10;
ytmp = get(gca,'ylim'); ysize = (ytmp(2)-ytmp(1))*0.10; 
rtmp = sqrt(xsize^2 + ysize^2);
quiver( sum(xtmp)/2 , sum(ytmp)/2 , rtmp*cos(pi/2-alp) , rtmp*sin(pi/2-alp) )


%% Get MESH East/North == Graph Horizontal / Vertical
[ Mesh.a , Mesh.c ] = ginput(1);
[ Mesh.b , Mesh.d ] = ginput(1);
if (Mesh.a > Mesh.b),tmp = Mesh.b;Mesh.b = Mesh.a;Mesh.a = tmp;end
if (Mesh.c > Mesh.d),tmp = Mesh.d;Mesh.d = Mesh.c;Mesh.c = tmp;end

Mesh.ne = ceil( ( Mesh.b - Mesh.a )/Mesh.de );
Mesh.nn = ceil( ( Mesh.d - Mesh.c )/Mesh.dn );
Mesh.b  = Mesh.a + Mesh.ne * Mesh.de;
Mesh.d  = Mesh.c + Mesh.nn * Mesh.dn;

Mesh.xe  = ( Mesh.a + Mesh.de/2) + ( ceil(( WS3D.utmEr - Mesh.a )/Mesh.de) - 1) * Mesh.de;
Mesh.xn  = ( Mesh.c + Mesh.dn/2) + ( ceil(( WS3D.utmNr - Mesh.c )/Mesh.dn) - 1) * Mesh.dn;

%%%%%%%%%%%%%
%% Temporary
%% WS coordinates
   tmp_grid.xe = Mesh.xe - ( Mesh.a + Mesh.b )/2;
   tmp_grid.xn = Mesh.xn - ( Mesh.c + Mesh.d )/2;
%% Get SITES sorted south to north, then west to east
   tmp_gridTAB = [ tmp_grid.xe(:) tmp_grid.xn(:) ];
   [tmp_sort , tmp_IDsort ] = sortrows( tmp_gridTAB , [2 1]);
%%%%%%%%%%%%%

h1 = plot( Mesh.xe , Mesh.xn );
set(h1,'Marker','s','MarkerSize',4,'MarkerEdgeColor','k','MarkerFaceColor','k','LineStyle','none');

[Xm,Ym]=meshgrid( [Mesh.a:Mesh.de:Mesh.b] , [Mesh.c:Mesh.dn:Mesh.d] );
h2 = line( Xm , Ym );
h3 = line( Xm', Ym');

h4=text( Mesh.xe(tmp_IDsort),Mesh.xn(tmp_IDsort)-dd,num2str([1:length(Mesh.xe)]','%4d'));
set(h4,'color','k','FontSize',8);

hold off

cOK=0;dlgTitle='Input / Update Mesh Limit';
while ~cOK,
    CumErr = sum( sqrt(  (WS3D.utmEr - Mesh.xe).^2 + (WS3D.utmNr - Mesh.xn).^2 ) );
    
    s_east = sprintf(' [  %.0f   %d   %.0f  ]', Mesh.a , Mesh.ne , Mesh.de );
    s_north= sprintf(' [  %.0f   %d   %.0f  ]', Mesh.c , Mesh.nn , Mesh.dn );
    s_cumer= sprintf(' %.3f ', CumErr );

    prompt={ strcat(' East ',s_east ) ; strcat(' North ',s_north) ; 'Cummulative Error ' };
    def = { s_east ; s_north ; s_cumer };
    answer=inputdlg(prompt,dlgTitle,lineNo,def);
    if      isequal( eval( char(def(1)) ) == eval(  char(answer(1)) ),[1 1 1]) & ...
            isequal( eval( char(def(2)) ) == eval(  char(answer(2)) ),[1 1 1]) , 
        cOK=1;
    else
        fig;hold on
        set( h1 , 'visible' , 'off' );
        set( h2 , 'visible' , 'off' );
        set( h3 , 'visible' , 'off' );
        set( h4 , 'visible' , 'off' );
        vect = eval( char( answer(1) ) );
        Mesh.a = vect(1); Mesh.ne = vect(2); Mesh.de = vect(3);
        vect = eval( char( answer(2) ) );
        Mesh.c = vect(1); Mesh.nn = vect(2); Mesh.dn = vect(3);
        
        Mesh.b  = Mesh.a + Mesh.ne * Mesh.de;
        Mesh.d  = Mesh.c + Mesh.nn * Mesh.dn;
        
        Mesh.xe  = ( Mesh.a + Mesh.de/2) + ( ceil(( WS3D.utmEr - Mesh.a )/Mesh.de) - 1) * Mesh.de;
        Mesh.xn  = ( Mesh.c + Mesh.dn/2) + ( ceil(( WS3D.utmNr - Mesh.c )/Mesh.dn) - 1) * Mesh.dn;


%%%%%%%%%%%%%
%% Temporary
%% WS coordinates
   tmp_grid.xe = Mesh.xe - ( Mesh.a + Mesh.b )/2;
   tmp_grid.xn = Mesh.xn - ( Mesh.c + Mesh.d )/2;
%% Get SITES sorted south to north, then west to east
   tmp_gridTAB = [ tmp_grid.xe(:) tmp_grid.xn(:) ];
   [tmp_sort , tmp_IDsort ] = sortrows( tmp_gridTAB , [2 1]);
%%%%%%%%%%%%%
        
        h1 = plot( Mesh.xe , Mesh.xn );
        set(h1,'Marker','s','MarkerSize',4,'MarkerEdgeColor','k','MarkerFaceColor','k','LineStyle','none');
        
        [Xm,Ym]=meshgrid( [Mesh.a:Mesh.de:Mesh.b] , [Mesh.c:Mesh.dn:Mesh.d] );
        h2 = line( Xm , Ym );
        h3 = line( Xm', Ym');
        
        h4=text( Mesh.xe(tmp_IDsort),Mesh.xn(tmp_IDsort)-dd,num2str([1:length(Mesh.xe)]','%4d'));
        set(h4,'color','k','FontSize',8);
        
    end
end
hold off


%% SAVE here the Mesh in real UTM coordinates
tab = ( transpose(ROT)*[ WS3D.utmEr'  ; WS3D.utmNr' ])';
Mesh_utm.StnE = tab(:,1);
Mesh_utm.StnN = tab(:,2);

tab = ( transpose(ROT)*[ Mesh.a  ; Mesh.c ])';
Mesh_utm.a = tab(1);
Mesh_utm.c = tab(2);

tab = ( transpose(ROT)*[ Mesh.b  ; Mesh.d ])';
Mesh_utm.b = tab(1);
Mesh_utm.d = tab(2);

tab = ( transpose(ROT)*[ Mesh.xe'  ; Mesh.xn' ])';
Mesh_utm.xe = tab(:,1);
Mesh_utm.xn = tab(:,2);

[ tmp.n , tmp.m ]  = size(Xm);
Xmr = reshape( Xm , tmp.n*tmp.m , 1 );
Ymr = reshape( Ym , tmp.n*tmp.m , 1 );
tab = ( transpose(ROT)*[ Xmr'  ; Ymr' ])';
Mesh_utm.grid_Xm = reshape( tab(:,1) , tmp.n , tmp.m );
Mesh_utm.grid_Ym = reshape( tab(:,2) , tmp.n , tmp.m );


%% qc plot
%%plot( WS3D.utmE , WS3D.utmN , 'k+' , Mesh_utm.StnE , Mesh_utm.StnN , 'ro' , Mesh_utm.a , Mesh_utm.c , 'b*' , Mesh_utm.xe , Mesh_utm.xn , 'b*' )
%%line( Mesh_utm.grid_Xm , Mesh_utm.grid_Ym )
%%line( Mesh_utm.grid_Xm', Mesh_utm.grid_Ym')
%%set(gca,'Dataaspectratio',[1 1 1])


%% GET MESH Z
ztmp = min(Mesh.de,Mesh.dn)/4;

lineNo=1;
dlgTitle='Input Z-Mesh';
prompt={ 'N * dz' ;...
         'N * dz' ;...
         'N * dz' ;...
         'N * dz' };
def = {  sprintf(' %d  *  %.0f ',  2 , 1.0*ztmp ) ;...
         sprintf(' %d  *  %.0f ',  4 , 1.5*ztmp ) ;...
         sprintf(' %d  *  %.0f ',  5 , 2.0*ztmp ) ;...
         sprintf(' %d  *  %.0f ',  4 , 3.0*ztmp ) };

cOK=0;
while ~cOK,
    answer=inputdlg(prompt,dlgTitle,lineNo,def);
    z1 = eval( char( answer( 1 ) ) );
    z2 = eval( char( answer( 2 ) ) );
    z3 = eval( char( answer( 3 ) ) );
    z4 = eval( char( answer( 4 ) ) );
    
    c1 = sprintf( '%s = %8.3f // %8.3f', char(answer(1)) , z1 , z1);
    c2 = sprintf( '%s = %8.3f // %8.3f', char(answer(2)) , z2 , z1+z2 );
    c3 = sprintf( '%s = %8.3f // %8.3f', char(answer(3)) , z3 , z1+z2+z3 );
    c4 = sprintf( '%s = %8.3f // %8.3f', char(answer(4)) , z4 , z1+z2+z3+z4 );
    ctmp = sprintf( '%s\n', c1 , c2 , c3 , c4 );
    ctmp = strcat(ctmp,sprintf( '\n\n%s','Is that correct?'));
    if isequal(questdlg( ctmp , 'Z-Mesh', 'Yes' , 'No' , 'Yes'),'Yes'),
        cOK=1;
    else
        def = answer;
    end
end

c=char(answer(1));k=strfind(c,'*');nz1 = str2num(c(1:k-1)); dz1 = str2num(c(1+k:end));
c=char(answer(2));k=strfind(c,'*');nz2 = str2num(c(1:k-1)); dz2 = str2num(c(1+k:end));
c=char(answer(3));k=strfind(c,'*');nz3 = str2num(c(1:k-1)); dz3 = str2num(c(1+k:end));
c=char(answer(4));k=strfind(c,'*');nz4 = str2num(c(1:k-1)); dz4 = str2num(c(1+k:end));

nz=nz1+nz2+nz3+nz4;
ztab = ones(nz,1);
ztab(1             : nz1            ) = dz1;
ztab(1+nz1         : nz1+nz2        ) = dz2;
ztab(1+nz1+nz2     : nz1+nz2+nz3    ) = dz3;
ztab(1+nz1+nz2+nz3 : nz1+nz2+nz3+nz4) = dz4;

Mesh.nz = nz;
Mesh.dz = ztab;

%%Mesh.ndec = [nz1 nz2 nz3 nz4];
%%Mesh.zdec = [dz1 dz2 dz3 dz4];


%% GET BACGROUND RHO
lineNo=1;
dlgTitle='Input Background Resistivity';
prompt={ 'Rho (ohm-m):' };
def = {  ' 100 ' };

answer=inputdlg(prompt,dlgTitle,lineNo,def);
Mesh.rhoBG = str2num( char( answer ) );


%% Back-up all
WS3D.Mesh     = Mesh;
WS3D.Mesh_utm = Mesh_utm;




%% output
varargout = { WS3D };
