function [ varargout ] = rd_surveyFile( varargin )
%%
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%
%%
if  nargin == 1
    fdat = varargin{ 1 };
else
    [ftmp,ptmp]=uigetfile('*','Select survey File');
    fdat = strcat(ptmp,ftmp);
end

TAB_xlat = [ ];
TAB_xlon = [ ];
TAB_utmN = [ ];
TAB_utmE = [ ];
TAB_elev = [ ];


fd = fopen( fdat ,'r');
if fd < 0, disp(['File ',fdat,' not found']);varargout = { -1 }; return;end

%%
%% HEADER 2D/3D of survey Files
%% Grid:: Grid or Project Title
%% Line:: 2D line or 3D grid
%% Datum:    datum for coordinates
%% UTM Zone: UTM zone of coordinates
%% header line
%%

tag = fgetl(fd);  info.Grid  = deblank( strjust( tag( strfind(tag,':')+1 : end ),'left' ) );
tag = fgetl(fd);  info.Line  = deblank( strjust( tag( strfind(tag,':')+1 : end ),'left' ) );
tag = fgetl(fd);  info.Datum = deblank( strjust( tag( strfind(tag,':')+1 : end ),'left' ) );
tag = fgetl(fd);  info.Uzone = deblank( strjust( tag( strfind(tag,':')+1 : end ),'left' ) );
tag = fgetl(fd);  
while isempty( findstr( tag , '' ) )
    tag = fgetl(fd);
end
%% start reading the survey with current tag has the first point
while ~isempty( findstr( tag , '' ) )
    id = strfind(tag,',');
    if ~isequal(length(id),9), 
        disp('This Line has a problem');
        disp( tag );
        varargout = { };
        return
    end
        
    clat = sscanf( tag( id(1)+1:id(2)-1 ), '%s' );
    clon = sscanf( tag( id(2)+1:id(3)-1 ), '%s' );
    utmN = sscanf( tag( id(3)+1:id(4)-1 ), '%f' );
    utmE = sscanf( tag( id(4)+1:id(5)-1 ), '%f' );
    elev = sscanf( tag( id(5)+1:id(6)-1 ), '%f' );
    %grdN = sscanf( tag( id(6)+1:id(7)-1 ), '%f' );
    %grdE = sscanf( tag( id(7)+1:id(8)-1 ), '%f' );
    %name = sscanf( tag( id(9)+1:  end   ), '%s' );
    
    % convert char Lat to number
    tmp = deblank(strrep(strrep(strrep(clat,'',' '),'"',' '),'''',' '));
    xlat=+1;if findstr( tmp , 'S' ), xlat=-1;end    
    vect= sscanf( tmp(1:end-1) , '%f' , 3 );  
    xlat = xlat*(vect(1) + (vect(2) + vect(3)/60)/60);
    % convert char Lon to number
    tmp = deblank(strrep(strrep(strrep(clon,'',' '),'"',' '),'''',' '));
    xlon=+1;if findstr( tmp , 'W' ), xlon=-1;end    
    vect= sscanf( tmp(1:end-1) , '%f' , 3 );  
    xlon = xlon*(vect(1) + (vect(2) + vect(3)/60)/60);
    
    
    TAB_xlat = [ TAB_xlat  xlat ];
    TAB_xlon = [ TAB_xlon  xlon ];
    TAB_utmN = [ TAB_utmN  utmN ];
    TAB_utmE = [ TAB_utmE  utmE ];
    TAB_elev = [ TAB_elev  elev ];
    
    tag = fgetl(fd);
end
fclose(fd);

%% OUTPUT
survey.info = info;
survey.xlat =  TAB_xlat(:);
survey.xlon =  TAB_xlon(:);
survey.utmN =  TAB_utmN(:);
survey.utmE =  TAB_utmE(:);
survey.elev =  TAB_elev(:);

varargout = { survey };
