function [ varargout ] = saveWS3DMTFiles( WS3D , Freq , itype , version )
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% VERSION 1 / 2
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%
%% 20090716: change npad to 7
%% 20090716: add 2/2/5 on the dim file
%% 20090729: bug fix on save init file (\n)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
varargout = { -1 };

if (nargin<4),return;end
if ~isstruct(WS3D),return;end
if isempty(Freq), return;end
if ~isequal(itype,round(itype)),return;end
if ~isequal(version,round(version)),return;end
if ~(itype>0 & itype<6),return;end
if ~(version>0 & version<3),return;end
if  (isequal(version,1) & itype>2),return;end

%% WS coordinates
grid.xe = WS3D.Mesh.xe - ( WS3D.Mesh.a + WS3D.Mesh.b )/2;
grid.xn = WS3D.Mesh.xn - ( WS3D.Mesh.c + WS3D.Mesh.d )/2;


%% Get SITES sorted south to north, then west to east
gridTAB = [ grid.xe(:) grid.xn(:) ];
[tmp , IDsort ] = sortrows( gridTAB , [2 1]);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Startup file:
%% Version V. = V1&V2 / V2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% V2     start up Type           itype
%% V.     data file               WS3D.froot,'_data'
%% V2     min_error_Z             5       [ only on itype=1,2,4,5 ]
%% V2     min_Error_T             15      [ only on itype=3,4,5 ]
%% V.     output file             WS3D.froot,'_out'
%% V.     initial model           WS3D.froot,'_init'
%% V.     prior model file        'default'
%% V.     control model index     'default'
%% V.     target RMS              1
%% V.     Max no of iteration     10
%% V.     model length scale      'default'
%% V.     Lagrange info           'default'
%% V.     error tol level         'default'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% START UP FILEs
fout = strcat( WS3D.froot,'_startup' );
fid  = fopen( fout ,'w');
if fid < 0, disp(['File ',fout,' not open']);varargout = { -1 }; return;end
if isequal( version , 2 )
    fprintf( fid , '%20s     %d\n' , 'INVERSION_TYPE'     , itype ); 
end
fprintf( fid , '%20s     %s\n' , 'DATA_FILE'          , strcat(WS3D.froot,'_data') ); 
if isequal( version , 2 )
    if isequal(itype,1) | isequal(itype,2) | isequal(itype,4) | isequal(itype,5)
        fprintf( fid , '%20s     %d\n' , 'MIN_ERROR_Z'        , 5 ); 
    end
    if isequal(itype,3) | isequal(itype,4) | isequal(itype,5)
        fprintf( fid , '%20s     %d\n' , 'MIN_ERROR_T'        , 15 );
    end
end
fprintf( fid , '%20s     %s\n' , 'OUTPUT_FILE'        , strcat(WS3D.froot,'_out') ); 
fprintf( fid , '%20s     %s\n' , 'INITIAL_MODEL_FILE' , strcat(WS3D.froot,'_init') ); 
fprintf( fid , '%20s     %s\n' , 'PRIOR_MODEL_FILE'   , 'default' ); 
fprintf( fid , '%20s     %s\n' , 'CONTROL_MODEL_INDEX', 'default' ); 
fprintf( fid , '%20s     %f\n' , 'TARGET_RMS'         , 1.00 ); 
fprintf( fid , '%20s     %d\n' , 'MAX_NO_ITERATION'   , 5 ); 
fprintf( fid , '%20s     %s\n' , 'MODEL_LENGTH_SCALE' , 'default' ); 
fprintf( fid , '%20s     %s\n' , 'LAGRANGE_INFO'      , 'default' ); 
fprintf( fid , '%20s     %s\n' , 'ERROR_TOL_LEVEL'    , 'default' ); 
fclose(  fid );
    
%% START UP FILE//FWD3D
status=mkdir('f3d/');
fout = strcat( 'f3d/',WS3D.froot,'_startup' );
fid  = fopen( fout ,'w');
if fid < 0, disp(['File ',fout,' not open']);varargout = { -1 }; return;end
if isequal( version , 2 )
    fprintf( fid , '%20s     %d\n' , 'INVERSION_TYPE'     , itype ); 
end
fprintf( fid , '%20s     %s\n' , 'DATA_FILE'          , strcat('../',WS3D.froot,'_data') ); 
if isequal( version , 2 )
    if isequal(itype,1) | isequal(itype,2) | isequal(itype,4) | isequal(itype,5)
        fprintf( fid , '%20s     %d\n' , 'MIN_ERROR_Z'        , 5 ); 
    end
    if isequal(itype,3) | isequal(itype,4) | isequal(itype,5)
        fprintf( fid , '%20s     %d\n' , 'MIN_ERROR_T'        , 15 );
    end
end
fprintf( fid , '%20s     %s\n' , 'OUTPUT_FILE'        , strcat(WS3D.froot,'_out') ); 
fprintf( fid , '%20s     %s\n' , 'INITIAL_MODEL_FILE' , strcat('../',WS3D.froot,'_init') ); 
fprintf( fid , '%20s     %s\n' , 'PRIOR_MODEL_FILE'   , 'default' ); 
fprintf( fid , '%20s     %s\n' , 'CONTROL_MODEL_INDEX', 'default' ); 
fprintf( fid , '%20s     %f\n' , 'TARGET_RMS'         , 1.00 ); 
fprintf( fid , '%20s     %d\n' , 'MAX_NO_ITERATION'   , 0 );  %% 0 to Run only forward 
fprintf( fid , '%20s     %s\n' , 'MODEL_LENGTH_SCALE' , 'default' ); 
fprintf( fid , '%20s     %s\n' , 'LAGRANGE_INFO'      , 'default' ); 
fprintf( fid , '%20s     %s\n' , 'ERROR_TOL_LEVEL'    , 'default' ); 
fclose(  fid );


%% MODEL File
fout = strcat( WS3D.froot,'_init' );
fid  = fopen( fout ,'w');
if fid < 0, disp(['File ',fout,' not open']);varargout = { -1 }; return;end
%% -- Compute Padding east
ne_padd = 7;
de_padd = zeros( WS3D.Mesh.ne + 2*ne_padd , 1 );
de_padd( [1:WS3D.Mesh.ne] + ne_padd ) = WS3D.Mesh.de;
for k=ne_padd:-1:1
    de_padd( k ) = 2*de_padd( k+1 );
end
for k=ne_padd+WS3D.Mesh.ne+1:ne_padd+WS3D.Mesh.ne+ne_padd
    de_padd( k ) = 2*de_padd( k-1 );
end
%% -- Compute Padding north
nn_padd = 7;
dn_padd = zeros( WS3D.Mesh.nn + 2*nn_padd , 1 );
dn_padd( [1:WS3D.Mesh.nn] + nn_padd ) = WS3D.Mesh.dn;
for k=nn_padd:-1:1
    dn_padd( k ) = 2*dn_padd( k+1 );
end
for k=nn_padd+WS3D.Mesh.nn+1:nn_padd+WS3D.Mesh.nn+nn_padd
    dn_padd( k ) = 2*dn_padd( k-1 );
end
%% -- Compute vert: Z
nz_padd = 7;
dz_padd = zeros( WS3D.Mesh.nz + 1*nz_padd , 1 );
dz_padd( 1:WS3D.Mesh.nz ) = WS3D.Mesh.dz;
for k=WS3D.Mesh.nz+1:WS3D.Mesh.nz+nz_padd
    dz_padd( k ) = 2*dz_padd( k-1 );
end
%% -- output
fprintf( fid , '# INITIAL MODEL\n' );
fprintf( fid , '%d %d %d %d\n' , length( dn_padd ) , length( de_padd ) , length( dz_padd ) , 1 ); 
fprintf( fid , '%10.2f %10.2f %10.2f %10.2f %10.2f\n' , dn_padd );
  if ~isequal( mod(  length(dn_padd) ,5),0),fprintf( fid , '\n');end
fprintf( fid , '%10.2f %10.2f %10.2f %10.2f %10.2f\n' , de_padd );
  if ~isequal( mod(  length(de_padd) ,5),0),fprintf( fid , '\n');end
fprintf( fid , '%10.2f %10.2f %10.2f %10.2f %10.2f\n' , dz_padd );
  if ~isequal( mod(  length(dz_padd) ,5),0),fprintf( fid , '\n');end
fprintf( fid , '%10.2f\n' , WS3D.Mesh.rhoBG );
fclose(fid);

%% DATA File
switch itype
case 1  %%  XXr    XXi    XYr    XYi    YXr    YXi    YYr    YYi
    itab= [ 03     04     05     06     07     08     09     10  ];
    fmt = '%16.8f %16.8f %16.8f %16.8f %16.8f %16.8f %16.8f %16.8f\n';
case 2  %%  XYr    XYi    YXr    YXi
    itab= [ 05     06     07     08 ];
    fmt = '%16.8f %16.8f %16.8f %16.8f\n';
case 3  %% ZXr    ZXi    ZYr    ZYi
    itab= [ 11     12     13     14 ];
    fmt = '%16.8f %16.8f %16.8f %16.8f\n';
case 4  %% XYr    XYi    YXr    YXi    ZXr    ZXi    ZYr    ZYi
    itab= [ 05     06     07     08     11     12     13     14 ];
    fmt = '%16.8f %16.8f %16.8f %16.8f %16.8f %16.8f %16.8f %16.8f\n';
case 5  %%  XXr    XXi    XYr    XYi    YXr    YXi    YYr    YYi    ZXr    ZXi    ZYr    ZYi
    fmt = '%16.8f %16.8f %16.8f %16.8f %16.8f %16.8f %16.8f %16.8f %16.8f %16.8f %16.8f %16.8f\n';
    itab= [ 03     04     05     06     07     08     09     10     11     12     13     14 ];
end

fout = strcat( WS3D.froot,'_data' );
fid  = fopen( fout ,'w');
if fid < 0, disp(['File ',fout,' not open']);varargout = { -1 }; return;end
switch version
case 1
    fprintf( fid , '%d %d %d\n' , WS3D.NS , length(Freq) , length( itab ) ); 
case 2
    fprintf( fid , '%d %d %d\n' , WS3D.NS , length(Freq) , itype ); 
end
fprintf( fid , '%s\n' , 'Station_Location: N-S' ); 
fprintf( fid , '%10.2f %10.2f %10.2f %10.2f %10.2f\n' , grid.xn(IDsort) );
  if ~isequal( mod(  length(grid.xn(IDsort)) ,5),0),fprintf( fid , '\n');end
fprintf( fid , '%s\n' , 'Station_Location: E-W' ); 
fprintf( fid , '%10.2f %10.2f %10.2f %10.2f %10.2f\n' , grid.xe(IDsort) ); 
  if ~isequal( mod(  length(grid.xe(IDsort)) ,5),0),fprintf( fid , '\n');end
%% -- DATA_Period
for k=1:length(Freq)
    id = find( (WS3D.data(:,2)==Freq(k))==1 );
    tmpDATA = WS3D.data(id,:);               %% Get the data @ Freq=F
    tmpDATA = tmpDATA(IDsort,:);             %% Sort sites to WS order 
    fprintf( fid , 'DATA_Period: %.8g\n' , 1/Freq(k) ); 
    fprintf( fid , fmt , tmpDATA(:,itab)' ); %% Print data
end
%% -- ERROR_Period
for k=1:length(Freq)
    id = find( (WS3D.data(:,2)==Freq(k))==1 );
    tmpDATA = WS3D.data(id,:);
    tmpDATA = tmpDATA(IDsort,:);
    fprintf( fid , 'ERROR_Period: %.8g\n' , 1/Freq(k) ); 
    fprintf( fid , strrep(fmt,'12.5f','0.2g') , (tmpDATA(:,itab)')*0+1.e-20 ); 
end
%% -- ERMAP_Period
for k=1:length(Freq)
    id = find( (WS3D.data(:,2)==Freq(k))==1 );
    tmpDATA = WS3D.data(id,:);
    tmpDATA = tmpDATA(IDsort,:);
    fprintf( fid , 'ERMAP_Period: %.8g\n' , 1/Freq(k) ); 
    fprintf( fid , strrep(fmt,'12.5f','0.1g') , (tmpDATA(:,itab)')*0+1. ); 
end
fclose(fid);


%% DIM File
fout = 'dim.h';
fid  = fopen( fout ,'w');
if fid < 0, disp(['File ',fout,' not open']);varargout = { -1 }; return;end
fprintf( fid , 'c ==========================================\n'); 
fprintf( fid , 'c DIMENSIONS\n'); 
fprintf( fid , 'c	NSMAX:	Sites\n'); 
fprintf( fid , 'c	NPMAX:	Periods\n'); 
fprintf( fid , 'c	NRMAX:	Responses [ 12 | 8 | 4 ]\n'); 
fprintf( fid , 'c	 XMAX:	Xmesh  North-South\n'); 
fprintf( fid , 'c	 YMAX:	Ymesh  East-West\n'); 
fprintf( fid , 'c	 ZMAX:	Zmesh  Depth\n'); 
fprintf( fid , 'c ==========================================\n'); 
fprintf( fid , '      INTEGER NSMAX, NPMAX, NRMAX\n'); 
fprintf( fid , '      INTEGER XMAX , YMAX , ZMAX\n'); 
fprintf( fid , 'c ==========================================\n');
fprintf( fid , '\n');
fprintf( fid , '      PARAMETER (NSMAX = %4d )\n' , WS3D.NS ); 
fprintf( fid , '      PARAMETER (NPMAX = %4d )\n' , length( Freq ) ); 
fprintf( fid , '      PARAMETER (NRMAX = %4d )\n' , length( itab ) ); 
fprintf( fid , '      PARAMETER ( XMAX = %4d )\n' , length( dn_padd ) + 2 ); 
fprintf( fid , '      PARAMETER ( YMAX = %4d )\n' , length( de_padd ) + 2); 
fprintf( fid , '      PARAMETER ( ZMAX = %4d )\n' , length( dz_padd ) + 5 + 7 ); 
fprintf( fid , '\n');
fprintf( fid , 'c ==========================================\n'); 
fclose(  fid );






%% EXTRA
%% Station File
fout = strcat( WS3D.froot,'_stn_grd' );
fid  = fopen( fout ,'w');
if fid < 0, disp(['File ',fout,' not open']);varargout = { -1 }; return;end
stn.xe = grid.xe( IDsort );
stn.xn = grid.xn( IDsort );
for k=1:length( stn.xe )
    fprintf( fid , '%15.2f   %15.2f   0.00\n' , stn.xe(k)  , stn.xn(k) ); 
end
fclose(fid);

fout = strcat( WS3D.froot,'_stn_utmR' );
fid  = fopen( fout ,'w');
if fid < 0, disp(['File ',fout,' not open']);varargout = { -1 }; return;end
stn.xe = WS3D.utmEr( IDsort );
stn.xn = WS3D.utmNr( IDsort );
for k=1:length( stn.xe )
    fprintf( fid , '%15.2f   %15.2f   0.00\n' , stn.xe(k)  , stn.xn(k) ); 
end
fclose(fid);

fout = strcat( WS3D.froot,'_stn_LL' );
fid  = fopen( fout ,'w');
if fid < 0, disp(['File ',fout,' not open']);varargout = { -1 }; return;end
stn.xe = WS3D.lon( IDsort );
stn.xn = WS3D.lat( IDsort );
for k=1:length( stn.xe )
    fprintf( fid , '%15.6f   %15.6f   0.00\n' , stn.xe(k)  , stn.xn(k) ); 
end
fclose(fid);


%% UBC Meshes - no padding

%% UBC Mesh File - Grid
fout = strcat( WS3D.froot,'_ubc.msh' );
fid  = fopen( fout ,'w');
if fid < 0, disp(['File ',fout,' not open']);varargout = { -1 }; return;end
fprintf( fid , '%d %d %d\n' , WS3D.Mesh.ne , WS3D.Mesh.nn , WS3D.Mesh.nz );
fprintf( fid , '%.2f %.2f %.2f\n' , -(WS3D.Mesh.de * WS3D.Mesh.ne )/2 , -(WS3D.Mesh.dn * WS3D.Mesh.nn )/2 , 0 );
fprintf( fid , '%.2f ', zeros(WS3D.Mesh.ne,1)+WS3D.Mesh.de );fprintf( fid , '\n');
fprintf( fid , '%.2f ', zeros(WS3D.Mesh.nn,1)+WS3D.Mesh.dn );fprintf( fid , '\n');
fprintf( fid , '%.2f ', WS3D.Mesh.dz );fprintf( fid , '\n');
fclose(fid);

%% UBC Mesh File - UTM
fout = strcat( WS3D.froot,'_utm.msh' );
fid  = fopen( fout ,'w');
if fid < 0, disp(['File ',fout,' not open']);varargout = { -1 }; return;end
fprintf( fid , '%d %d %d\n' , WS3D.Mesh.ne , WS3D.Mesh.nn , WS3D.Mesh.nz );
fprintf( fid , '%.2f %.2f %.2f\n' , WS3D.Mesh.a , WS3D.Mesh.c , 0 );
fprintf( fid , '%.2f ', zeros(WS3D.Mesh.ne,1)+WS3D.Mesh.de );fprintf( fid , '\n');
fprintf( fid , '%.2f ', zeros(WS3D.Mesh.nn,1)+WS3D.Mesh.dn );fprintf( fid , '\n');
fprintf( fid , '%.2f ', WS3D.Mesh.dz );fprintf( fid , '\n');
fclose(fid);


%% END
varargout = { 1 }; 