function [ varargout ] = plot_Mesh( varargin )
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%

if  nargin == 1 & isstruct( varargin{ 1 } ) & isfield( varargin{ 1 },'utmE') & isfield( varargin{ 1 },'utmN') & isfield( varargin{ 1 },'Mesh')
    WS3D = varargin{ 1 };
else
    varargout = { -1 }; 
    return;
end


%% WS coordinates
grid.xe = WS3D.Mesh.xe - ( WS3D.Mesh.a + WS3D.Mesh.b )/2;
grid.xn = WS3D.Mesh.xn - ( WS3D.Mesh.c + WS3D.Mesh.d )/2;
%% Get SITES sorted south to north, then west to east
gridTAB = [ grid.xe(:) grid.xn(:) ];
[tmp , IDsort ] = sortrows( gridTAB , [2 1]);

deltaE = ( max( WS3D.utmEr ) - min( WS3D.utmEr ) ) * (10/100);
deltaN = ( max( WS3D.utmNr ) - min( WS3D.utmNr ) ) * (10/100);
a = floor( min( WS3D.utmEr-deltaE ) ) ;
b =  ceil( max( WS3D.utmEr+deltaE ) ) ;
c = floor( min( WS3D.utmNr-deltaN ) ) ;
d =  ceil( max( WS3D.utmNr+deltaN ) ) ;

dd=( max( WS3D.utmNr ) - min( WS3D.utmNr ) )/50;

figure;hold on;
%% Plot UTM sites
set(plot( WS3D.utmEr,WS3D.utmNr),'Marker','o','MarkerSize',2,'MarkerEdgeColor','r','MarkerFaceColor','r','LineStyle','none');

%% ADD UTM ID to UTM site
if strcmp( questdlg('Show UTM Site ID?', '', 'Yes', 'No', 'No') , 'Yes')
    set(text( WS3D.utmEr,WS3D.utmNr+dd,num2str([1:length(WS3D.utmE)]','%4d' ) ),'Color','r','FontSize',8);
end


%% Plot WS sites
set(plot( WS3D.Mesh.xe,WS3D.Mesh.xn),'Marker','s','MarkerSize',4,'MarkerEdgeColor','k','MarkerFaceColor','k','LineStyle','none');
%%set(plot( WS3D.utmEr(IDsort),WS3D.utmNr(IDsort)),'Marker','s','MarkerSize',4,'MarkerEdgeColor','k','MarkerFaceColor','k','LineStyle','none');

%% ADD WS3D ID on UTM site
if strcmp( questdlg('Show WS3D Site ID?', '', 'Yes', 'No', 'Yes') , 'Yes')
    set(text( WS3D.utmEr(IDsort),WS3D.utmNr(IDsort)-dd,num2str([1:length(WS3D.utmE)]','%4d')),'color','k','FontSize',8);end
end


%% Plot WS mesh
[Xm,Ym]=meshgrid( [WS3D.Mesh.a:WS3D.Mesh.de:WS3D.Mesh.b] , [WS3D.Mesh.c:WS3D.Mesh.dn:WS3D.Mesh.d] );
line( Xm , Ym );
line( Xm', Ym');

%% Others
set(gca , 'Xlim' , [a b] , 'Ylim' , [c d] , 'DataAspectRatio', [1 1 1] );
xlabel('UTM East(r)');
ylabel('UTM North(r)');


if strcmp( questdlg('Save Graphic?', '', 'Yes', 'No', 'No') , 'Yes')
    eval( [ 'print -dpng ' WS3D.froot '_mesh2.png' ] )
end

