function [ varargout ] = pack_WS3DwSRV( varargin )
%%
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%

if     nargin < 2
    varargout = { -1 };
    return
else
    cOK_TBL=zeros(2,1); 
    cOK_SRV=zeros(2,1); 
    for k=1:2
        cOK_TBL(k) = ...
            isstruct( varargin{k } ) & ...
            isfield( varargin{ k },'xlat') & ...
            isfield( varargin{ k },'xlon') & ...
            isfield( varargin{ k },'utmN') & ...
            isfield( varargin{ k },'utmE') & ...
            isfield( varargin{ k },'elev') & ...
            isfield( varargin{ k },'data') ;
        cOK_SRV(k) = ...
            isstruct( varargin{k } ) & ...
            isfield( varargin{ k },'lat' ) & ...
            isfield( varargin{ k },'lon' ) & ...
            isfield( varargin{ k },'utmN') & ...
            isfield( varargin{ k },'utmE') & ...
            isfield( varargin{ k },'elev') ;
    end
    
    if ~isequal( [ cOK_TBL(1) ; cOK_SRV(2) ] , ones(2,1) ), 
        if ~isequal( [ cOK_TBL(2) ; cOK_SRV(1) ] , ones(2,1) ), 
            varargout = { };
            return;
        else
            WS3D = varargin{ 2 };
            SURV = varargin{ 1 };
        end
    else
        WS3D = varargin{ 1 };
        SURV = varargin{ 2 };
    end
end

if ( length( WS3D.lat ) > length( SURV.xlat ) )
    disp('Incomplete SURVEY / Review input');
    varargout = {  };
    return;
end

cOK = zeros( length(WS3D.lat) , 1 );







delta=100;
for k=1:length( WS3D.lat  )
    id=find(sum([(abs(WS3D.utmN(k)-SURV.utmN)<delta) (abs(WS3D.utmE(k)-SURV.utmE)<delta)],2) == 2);

    if ( ~isempty(id) & isequal(length(id),1) )
        WS3D.lat( k) = SURV.xlat( id );
        WS3D.lon( k) = SURV.xlon( id );
        WS3D.utmN(k) = SURV.utmN( id );
        WS3D.utmE(k) = SURV.utmE( id );
        WS3D.elev(k) = SURV.elev( id );
        cOK(k) = 1;
    end    
end

varargout = {  };
if ( isequal( cOK , ones( length(WS3D.lat),1) ) )
    
    
    figure;
    subplot(2,1,1)
    deltaE = ( max( WS3D.lon ) - min( WS3D.lon ) ) * (10/100);
    deltaN = ( max( WS3D.lat ) - min( WS3D.lat ) ) * (10/100);
    a = floor( min( WS3D.lon-deltaE )*100 )/100 ;
    b =  ceil( max( WS3D.lon+deltaE )*100 )/100 ;
    c = floor( min( WS3D.lat-deltaN )*100 )/100 ;
    d =  ceil( max( WS3D.lat+deltaN )*100 )/100 ;

    set( plot( WS3D.lon ,WS3D.lat ,'rs'),'Marker','s','MarkerSize',3,'MarkerEdgeColor','r','MarkerFaceColor','r','LineStyle','none' ); hold on
    set( plot( SURV.xlon,SURV.xlat,'b*'),'Marker','*','MarkerSize',3,'MarkerEdgeColor','b','MarkerFaceColor','r','LineStyle','none' ); hold off
    xlabel('longitude E');
    ylabel('latitude N');
    legend(['TBL' ; 'SRV'],-1);
    set(gca , 'Xlim' , [a b] , 'Ylim' , [c d] , 'DataAspectRatio', [1 1 1] );

    subplot(2,1,2)
    deltaE = ( max( WS3D.utmE ) - min( WS3D.utmE ) ) * (10/100);
    deltaN = ( max( WS3D.utmN ) - min( WS3D.utmN ) ) * (10/100);
    a = floor( min( WS3D.utmE-deltaE )*100 )/100 ;
    b =  ceil( max( WS3D.utmE+deltaE )*100 )/100 ;
    c = floor( min( WS3D.utmN-deltaN )*100 )/100 ;
    d =  ceil( max( WS3D.utmN+deltaN )*100 )/100 ;
    
    set( plot( WS3D.utmE/1e3,WS3D.utmN/1e3,'rs'),'Marker','s','MarkerSize',3,'MarkerEdgeColor','r','MarkerFaceColor','r','LineStyle','none' ); hold on
    set( plot( SURV.utmE/1e3,SURV.utmN/1e3,'b*'),'Marker','*','MarkerSize',3,'MarkerEdgeColor','b','MarkerFaceColor','r','LineStyle','none' ); hold off
    xlabel('utmE (km)');
    ylabel('utmN (km)');
    legend(['TBL' ; 'SRV'],-1);
    set(gca , 'Xlim' , [a b]/1e3 , 'Ylim' , [c d]/1e3 , 'DataAspectRatio', [1 1 1] );
    
    if strcmp( questdlg('Save Graphic?', '', 'Yes', 'No', 'No') , 'Yes')
        eval( [ 'print -dpng ' WS3D.froot '_TBLwSRV.png' ] )
    end
    
    varargout = { WS3D };
end
return
