function [ varargout ] = plot_MeshUTM( varargin )
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%

if  nargin == 1 & isstruct( varargin{ 1 } ) & isfield( varargin{ 1 },'utmE') & isfield( varargin{ 1 },'utmN') & isfield( varargin{ 1 },'Mesh_utm')
    WS3D = varargin{ 1 };
else
    varargout = { -1 }; 
    return;
end


tmp.E = [ WS3D.utmE ; WS3D.Mesh_utm.a ];
tmp.N = [ WS3D.utmN ; WS3D.Mesh_utm.c ];

deltaE = ( max( tmp.E ) - min( tmp.E ) ) * (20/100);
deltaN = ( max( tmp.N ) - min( tmp.N ) ) * (20/100);

a = floor( min( tmp.E - deltaE ) ) ;
b =  ceil( max( tmp.E + deltaE ) ) ;
c = floor( min( tmp.N - deltaN ) ) ;
d =  ceil( max( tmp.N + deltaN ) ) ;

dd=( max( WS3D.utmN ) - min( WS3D.utmN ) )/50;

figure;hold on;
%% Plot UTM sites
set(plot( WS3D.utmE,WS3D.utmN),'Marker','o','MarkerSize',2,'MarkerEdgeColor','r','MarkerFaceColor','r','LineStyle','none');

%% ADD UTM ID to UTM site
if strcmp( questdlg('Show UTM Site ID?', '', 'Yes', 'No', 'No') , 'Yes')
    set(text( WS3D.utmE,WS3D.utmN+dd,num2str([1:length(WS3D.utmE)]','%4d' ) ),'Color','r','FontSize',8);
end

%% Plot WS sites
set(plot( WS3D.Mesh_utm.StnE,WS3D.Mesh_utm.StnN),'Marker','+','MarkerSize',4,'MarkerEdgeColor','k','MarkerFaceColor','k','LineStyle','none');


%% Plot WS Mesh origin
set(plot( WS3D.Mesh_utm.a,WS3D.Mesh_utm.c),'Marker','*','MarkerSize',4,'MarkerEdgeColor','b','MarkerFaceColor','b','LineStyle','none');


%% Plot WS Mesh (center of cell)
line( WS3D.Mesh_utm.grid_Xm , WS3D.Mesh_utm.grid_Ym )
line( WS3D.Mesh_utm.grid_Xm', WS3D.Mesh_utm.grid_Ym')


%% Plot WS Mesh point (center of cell)
if strcmp( questdlg('Show center of cell?', '', 'Yes', 'No', 'No') , 'Yes')
   set(plot( WS3D.Mesh_utm.xe,WS3D.Mesh_utm.xn),'Marker','*','MarkerSize',4,'MarkerEdgeColor','b','MarkerFaceColor','b','LineStyle','none');
end



%% Others
set(gca , 'Xlim' , [a b] , 'Ylim' , [c d] , 'DataAspectRatio', [1 1 1] );
xlabel('UTM East');
ylabel('UTM North');


if strcmp( questdlg('Save Graphic?', '', 'Yes', 'No', 'No') , 'Yes')
    eval( [ 'print -dpng ' WS3D.froot '_mesh_utm.png' ] )
end

