function [ varargout ] = rd_GeotoolsTBL( varargin )
%%
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%
%% 20090913: addin output.elev field

if  nargin == 1
    fdat = varargin{ 1 };
else
    [ftmp,ptmp]=uigetfile('*.tbl','Select TBL-File');
    fdat = strcat(ptmp,ftmp);
end

NF  = 0;
NS  = 0;
MAT = [];

fd = fopen( fdat ,'r');
if fd < 0, disp(['File ',fdat,' not found']);varargout = { -1 }; return;end


%% Unit Conversion
CONV = 4.0 * pi / 1.0e4; % 1 mV/km/nt --> (4*pi/1e4) ohm:[V/m]/[A/m]



dummy = fgetl(fd); %% Quantec Title

%% LATLON
tag = fgetl(fd);
while isempty( findstr( tag , 'LatLong' ) )
    tag = fgetl(fd);
end
dummy = fgetl(fd); %% Location title
cline = fgetl(fd); id = strfind(cline,'=');
Nsite = sscanf( cline(id(1)+1:length(cline)), '%d');

TAB_lat   = zeros(1,Nsite);
TAB_lon   = zeros(1,Nsite);
for is=1:Nsite
     cline = fgetl(fd);
     cname   = sscanf( cline(01:16), '%s' );
     TAB_name(is,(1:length(cname))) = cname';     %MGH added
     TAB_name_short (is,((length(cname)-2):(length(cname))))=cname((length(cname)-2):(length(cname)));
     TAB_lat(is) = sscanf( cline(17:32), '%f' );
     TAB_lon(is) = sscanf( cline(33:48), '%f' );
end


%% UTM
tag = fgetl(fd);
while isempty( findstr( tag , 'UTM' ) )
    tag = fgetl(fd);
end
dummy = fgetl(fd); %% Location title
cline = fgetl(fd); id = strfind(cline,'=');
Ntemp = sscanf( cline(id(1)+1:length(cline)), '%d');
if ~isequal(Nsite,Ntemp),return,end

TAB_north = zeros(1,Nsite);
TAB_east  = zeros(1,Nsite);
% sname = zeros(1,Nsite);  %MGH
for is=1:Nsite
     cline = fgetl(fd);
%         sname(is) = sscanf( cline(01:16), '%f' );  %MGH
     TAB_north(is) = sscanf( cline(17:32), '%f' );
     TAB_east(is)  = sscanf( cline(33:48), '%f' );
end

%% DATA
tag = fgetl(fd);
while isempty( findstr( tag , 'Data' ) )
    tag = fgetl(fd);
end

ik=0;
xf_ref = [];
for is=1:Nsite
    cline = fgetl(fd); %% SITE Name
    cline = fgetl(fd); id = strfind(cline,'='); 
    Nfreq = sscanf( cline(id(1)+1:length(cline)), '%d');
    cline = fgetl(fd); %% SITE Labels
    for ip=1:Nfreq
        vect = fscanf( fd , '%f' , 13 );cline = fgetl(fd);
        
        ik = ik + 1;
        
        %% WARNING: I use '-' because I need to CONJUGATE(Z)
        data( ik , 01 ) = is;               %% iSite code
        data( ik , 02 ) =  vect(  1 );      %% Freq
        data( ik , 03 ) =  vect(  2 )*CONV; %% Zxxr
        data( ik , 04 ) = -vect(  3 )*CONV; %% Zxxi
        data( ik , 05 ) =  vect(  4 )*CONV; %% Zxyr
        data( ik , 06 ) = -vect(  5 )*CONV; %% Zxyi
        data( ik , 07 ) =  vect(  6 )*CONV; %% Zyxr
        data( ik , 08 ) = -vect(  7 )*CONV; %% Zyxi
        data( ik , 09 ) =  vect(  8 )*CONV; %% Zyyr
        data( ik , 10 ) = -vect(  9 )*CONV; %% Zyyi
        data( ik , 11 ) =  vect( 10 )*1;    %% Tzxr
        data( ik , 12 ) =  vect( 11 )*1;    %% Tzxi
        data( ik , 13 ) =  vect( 12 )*1;    %% Tzyr
        data( ik , 14 ) =  vect( 13 )*1;    %% Tzyi
        
        if  isempty( find( xf_ref == data(ik,02) ) )
            xf_ref = [ xf_ref ; data(ik,02) ];
        end
        
    end
end
if (fd),fclose(fd);end

%% OUTPUT
output.lat  =  TAB_lat(:);
output.lon  =  TAB_lon(:);
output.utmN =  TAB_north(:);
output.utmE =  TAB_east(:);
output.elev =  zeros(length(output.utmE),1);
output.data =  data;

output.sitename  = TAB_name_short;   %MGH added

varargout = { output };
