function [ rms ] = calcul_rms( cdata , cderr , cresp )
%%
%%  calcul_rms( cdata , cderr , cresp )
%%
%%  Computed difference between Observed / Calculated Impedances from Files
%%    cdata: Observed   Impedances
%%    cderr: Observed   Impedances Errors
%%    cresp: Calculated Impedances
%%
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%

%% example
%% cdata  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d.data';
%% cderr  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d.error';
%% cresp  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d_resp.05';

rms = [];

%% Load Observed / Calculated Data
[ MTobs ] = read_data( cdata );
[ MTerr ] = read_data( cderr );
[ MTcal ] = read_data( cresp );
if isempty( MTobs ) | isempty( MTerr ) | isempty( MTcal ) ,return;end

%% Load Observed / Calculated Data
rms_ar = reshape( abs(MTcal.ZRes(:, 1,:)-MTobs.ZRes(:, 1,:))./MTerr.ZRes(:, 1,:) , MTobs.Np , MTobs.Ns );
rms_ai = reshape( abs(MTcal.ZRes(:, 2,:)-MTobs.ZRes(:, 2,:))./MTerr.ZRes(:, 2,:) , MTobs.Np , MTobs.Ns );
rms_br = reshape( abs(MTcal.ZRes(:, 3,:)-MTobs.ZRes(:, 3,:))./MTerr.ZRes(:, 3,:) , MTobs.Np , MTobs.Ns );
rms_bi = reshape( abs(MTcal.ZRes(:, 4,:)-MTobs.ZRes(:, 4,:))./MTerr.ZRes(:, 4,:) , MTobs.Np , MTobs.Ns );
RMS_site = [ rms_ar ; rms_ai ; rms_br ; rms_bi];
if (MTobs.Nr>4)
    rms_cr = reshape( abs(MTcal.ZRes(:, 5,:)-MTobs.ZRes(:, 5,:))./MTerr.ZRes(:, 5,:) , MTobs.Np , MTobs.Ns );
    rms_ci = reshape( abs(MTcal.ZRes(:, 6,:)-MTobs.ZRes(:, 6,:))./MTerr.ZRes(:, 6,:) , MTobs.Np , MTobs.Ns );
    rms_dr = reshape( abs(MTcal.ZRes(:, 7,:)-MTobs.ZRes(:, 7,:))./MTerr.ZRes(:, 7,:) , MTobs.Np , MTobs.Ns );
    rms_di = reshape( abs(MTcal.ZRes(:, 8,:)-MTobs.ZRes(:, 8,:))./MTerr.ZRes(:, 8,:) , MTobs.Np , MTobs.Ns );
    RMS_site = [ RMS_site ; rms_cr ; rms_ci ; rms_dr ; rms_di ];
end
if (MTobs.Nr>8)
    rms_er = reshape( abs(MTcal.ZRes(:, 9,:)-MTobs.ZRes(:, 9,:))./MTerr.ZRes(:, 9,:) , MTobs.Np , MTobs.Ns );
    rms_ei = reshape( abs(MTcal.ZRes(:,10,:)-MTobs.ZRes(:,10,:))./MTerr.ZRes(:,10,:) , MTobs.Np , MTobs.Ns );
    rms_fr = reshape( abs(MTcal.ZRes(:,11,:)-MTobs.ZRes(:,11,:))./MTerr.ZRes(:,11,:) , MTobs.Np , MTobs.Ns );
    rms_fi = reshape( abs(MTcal.ZRes(:,12,:)-MTobs.ZRes(:,12,:))./MTerr.ZRes(:,12,:) , MTobs.Np , MTobs.Ns );
    RMS_site = [ RMS_site ; rms_er ; rms_ei ; rms_fr ; rms_fi ];
end
RMS_tot = sqrt( sum(sum( RMS_site.^2 , 1),2) / (MTobs.Ns*MTobs.Np*MTobs.Nr) );
RMS_stn = sqrt(     sum( RMS_site.^2 , 1)    / (         MTobs.Np*MTobs.Nr) );
RMS_loc = MTobs.loc;

rms = { RMS_tot ; RMS_stn ; RMS_loc };
