function [ rms ] = calcul_rms( cdata , cderr , cresp )
%%
%%  calcul_rms( cdata , cderr , cresp )
%%
%%  Computed difference between Observed / Calculated Impedances from Files
%%    cdata: Observed   Impedances
%%    cderr: Observed   Impedances Errors
%%    cresp: Calculated Impedances
%%
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%

%% example
%% cdata  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d.data';
%% cderr  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d.error';
%% cresp  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d_resp.05';

rms = [];

%% Load Observed / Calculated Data
[ MTobs ] = read_data( cdata );
[ MTerr ] = read_data( cderr );
[ MTcal ] = read_data( cresp );
if isempty( MTobs ) | isempty( MTerr ) | isempty( MTcal ) ,return;end

ntot = MTcal.Ns * MTcal.Np;

%% Load Observed / Calculated Data
rms_zxx_r = [];
rms_zxx_i = [];
rms_zxy_r = [];
rms_zxy_i = [];
rms_zyx_r = [];
rms_zyx_i = [];
rms_zyy_r = [];
rms_zyy_i = [];
zero_error = zeros( ntot , 1 );

if ~isequal( reshape( MTerr.Zxx.r , ntot , 1) , zero_error )
    rms_zxx_r = abs( reshape( MTcal.Zxx.r , ntot , 1) - reshape( MTobs.Zxx.r , ntot , 1) )./reshape( MTerr.Zxx.r , ntot , 1) ;end
if ~isequal( reshape( MTerr.Zxx.i , ntot , 1) , zero_error )
    rms_zxx_i = abs( reshape( MTcal.Zxx.i , ntot , 1) - reshape( MTobs.Zxx.i , ntot , 1) )./reshape( MTerr.Zxx.i , ntot , 1) ;end
if ~isequal( reshape( MTerr.Zxy.r , ntot , 1) , zero_error )
    rms_zxy_r = abs( reshape( MTcal.Zxy.r , ntot , 1) - reshape( MTobs.Zxy.r , ntot , 1) )./reshape( MTerr.Zxy.r , ntot , 1) ;end
if ~isequal( reshape( MTerr.Zxy.i , ntot , 1) , zero_error )
    rms_zxy_i = abs( reshape( MTcal.Zxy.i , ntot , 1) - reshape( MTobs.Zxy.i , ntot , 1) )./reshape( MTerr.Zxy.i , ntot , 1) ;end
if ~isequal( reshape( MTerr.Zyx.r , ntot , 1) , zero_error )
    rms_zyx_r = abs( reshape( MTcal.Zyx.r , ntot , 1) - reshape( MTobs.Zyx.r , ntot , 1) )./reshape( MTerr.Zyx.r , ntot , 1) ;end
if ~isequal( reshape( MTerr.Zyx.i , ntot , 1) , zero_error )
    rms_zyx_i = abs( reshape( MTcal.Zyx.i , ntot , 1) - reshape( MTobs.Zyx.i , ntot , 1) )./reshape( MTerr.Zyx.i , ntot , 1) ;end
if ~isequal( reshape( MTerr.Zyy.r , ntot , 1) , zero_error )
    rms_zyy_r = abs( reshape( MTcal.Zyy.r , ntot , 1) - reshape( MTobs.Zyy.r , ntot , 1) )./reshape( MTerr.Zyy.r , ntot , 1) ;end
if ~isequal( reshape( MTerr.Zyy.i , ntot , 1) , zero_error )
    rms_zyy_i = abs( reshape( MTcal.Zyy.i , ntot , 1) - reshape( MTobs.Zyy.i , ntot , 1) )./reshape( MTerr.Zyy.i , ntot , 1) ;end

rms = [ rms_zxx_r ; rms_zxx_i ; ...
        rms_zxy_r ; rms_zxy_i ; ...
        rms_zyx_r ; rms_zyx_i ; ...
        rms_zyy_r ; rms_zyy_i ];

rms = rms( ~isnan(rms) );
rms = sqrt( sum( rms.^2 ) / length(rms) );

