function [ ierr ] = exportWS2UBC( cmodel )
%%
%% export the WS 3D MT model stored in 'cmodel'
%% to:
%%     mesh file: 'cmodel'_ubc.msh
%%     cond file: 'cmodel'_ubc.con
%% 
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%

%% example: 
%% cmodel = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\init3d2.test';
%% cmodel = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d_model.05';

ierr =1;

scale = 1.0; % no scale

%% Load Model
[ Mesh.north , Mesh.east , Mesh.depth , Model.res ] = read_model(cmodel);
Model.con = 1./Model.res;

%% NS-axis
nn = length( Mesh.north );
vect = [ 0 ;  cumsum( Mesh.north(:) ) ]/scale - sum( Mesh.north )/(2.*scale);
Mesh.north_c = ( vect(1:end-1) + vect(2:end) )/2;
%% EW-axis
ne = length( Mesh.east );
vect = [ 0 ;  cumsum( Mesh.east(:)  ) ]/scale - sum( Mesh.east  )/(2.*scale);
Mesh.east_c = ( vect(1:end-1) + vect(2:end) )/2;
%% Depth-axis
nz = length( Mesh.depth );
vect = [ 0 ; -cumsum( Mesh.depth(:) ) ]/scale;
Mesh.depth_c = vect(1:length(Mesh.depth));

%%
%% Mesh File
cmesh  = [ strrep(cmodel,'.','_') '_ubc.msh' ];
fidmsh = fopen(cmesh,'w');if ( fidmsh <0 ),disp(['Can not open ' cmesh]);ierr=0;return;end
fprintf( fidmsh , '%d %d %d\n' , ne , nn , nz );
fprintf( fidmsh , '%.2f %.2f %.2f\n' , -sum( Mesh.east  )/2 , -sum( Mesh.north )/2 , 0 );
fprintf( fidmsh , '%.2f ', Mesh.east  );fprintf( fidmsh , '\n');
fprintf( fidmsh , '%.2f ', Mesh.north );fprintf( fidmsh , '\n');
fprintf( fidmsh , '%.2f ', Mesh.depth );fprintf( fidmsh , '\n');
fclose(fidmsh);

%%
%% Cond Files
ccond = [ strrep(cmodel,'.','_') '_ubc.con'];
fidcon = fopen(ccond,'w');if ( fidcon <0 ),disp(['Can not open ' ccond]);ierr=0;return;end
for kn=1:nn
    for ke=1:ne
        for kz=1:nz
            fprintf(fidcon, '%f\n' , Model.con( kn , ke , kz ) );
        end
    end
end
fclose(fidcon);

