function plot_imped( Robs , Iobs , Rcal , Ical , Mode )
%%
%%  plot_imped( Robs , Iobs , Rcal , Ical , Mode )
%%
%%  PLOT Observed / Calculated Impedances
%%
%%       Output an 2x2 subfigure
%%                   [ RealZ_obs  ImagZ_obs ]
%%                   [ RealZ_cal  ImagZ_cal ]
%%    x-axis is Station ID
%%    y-axis is Period  ID (reversed: 1st < 2nd < .. < last period )
%%
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%

%% Load Colormap
colormap( getHSV );

% labels
xlab = 'station no.';
ylab = 'period no.';

% titles
tt.obs.r = strcat('Real Z_{' , Mode , '} : Observed');
tt.obs.i = strcat('Imag Z_{' , Mode , '} : Observed');
tt.cal.r = strcat('Real Z_{' , Mode , '} : Calculated');
tt.cal.i = strcat('Imag Z_{' , Mode , '} : Calculated');

% min/max
Rmax = max( [ Robs(:) ; Rcal(:) ] );
Rmin = min( [ Robs(:) ; Rcal(:) ] );
Imax = max( [ Iobs(:) ; Ical(:) ] );
Imin = min( [ Iobs(:) ; Ical(:) ] );

set(gcf,'Renderer','opengl')

%% Real-Z - Obs
subplot(2,2,1); 
imagesc( Robs(:,:) ); grid on
%%xlabel( xlab ); 
ylabel( ylab ); 
title( tt.obs.r );
caxis( [ Rmin Rmax ] ); colorbar;


%% Imag-Z - Obs
subplot(2,2,2);
imagesc( Iobs(:,:) ); grid on
%%xlabel( xlab ); 
%%ylabel( ylab ); 
title( tt.obs.i );
caxis( [ Imin Imax ] ); colorbar;


%% Real-Z - Cal
subplot(2,2,3);
imagesc( Rcal(:,:) ); grid on
xlabel( xlab ); 
ylabel( ylab ); 
title( tt.cal.r );
caxis( [ Rmin Rmax ] ); colorbar;


%% Imag-Z - Cal
subplot(2,2,4);
imagesc( Ical(:,:) ); grid on
xlabel( xlab ); 
%%ylabel( ylab ); 
title( tt.cal.i );
caxis( [ Imin Imax ] ); colorbar;
