function plot_obscal( cdata , cresp )
%%
%%  plot_obscal( cdata , cresp )
%%
%%  PLOT Observed / Calculated Impedances from Files
%%    cdata: Observed   Impedances
%%    cresp: Calculated Impedances
%%
%%       Output 4 Figures (Zxx - Zxy - Zyx - Zyy)
%%
%%     call plot_imped
%%
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%

%% example
%% cdata  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d.data';
%% cresp  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d_resp.05';


%% Load Observed / Calculated Data
[ MTobs ] = read_data( cdata );
[ MTcal ] = read_data( cresp );
if isempty( MTobs ) | isempty( MTcal ) ,return;end

%% Plot Impedances

if ( MTobs.Nr == 8 )
hf1 = figure(1);  clf; set( hf1 , 'name' , 'Zxx');
plot_imped( MTobs.Zxx.r , MTobs.Zxx.i , MTcal.Zxx.r , MTcal.Zxx.i , 'xx' );
end

hf2 = figure(2);  clf; set( hf2 , 'name' , 'Zxy');
plot_imped( MTobs.Zxy.r , MTobs.Zxy.i , MTcal.Zxy.r , MTcal.Zxy.i , 'xy' );

hf3 = figure(3);  clf; set( hf3 , 'name' , 'Zyx');
plot_imped( MTobs.Zyx.r , MTobs.Zyx.i , MTcal.Zyx.r , MTcal.Zyx.i , 'yx' );

if ( MTobs.Nr == 8 )
hf4 = figure(4);  clf; set( hf4 , 'name' , 'Zyy');
plot_imped( MTobs.Zyy.r , MTobs.Zyy.i , MTcal.Zyy.r , MTcal.Zyy.i , 'yy' );
end

%% Plot RhoApp & Phase

if ( MTobs.Nr == 8 )
hf1 = figure(5);  clf; set( hf1 , 'name' , 'Zxx');
plot_rhophs( MTobs.Zxx.rho , MTobs.Zxx.phs , MTcal.Zxx.rho , MTcal.Zxx.phs , 'xx' );
end

hf2 = figure(6);  clf; set( hf2 , 'name' , 'Zxy');
plot_rhophs( MTobs.Zxy.rho , MTobs.Zxy.phs , MTcal.Zxy.rho , MTcal.Zxy.phs , 'xy' );

hf3 = figure(7);  clf; set( hf3 , 'name' , 'Zyx');
plot_rhophs( MTobs.Zyx.rho , MTobs.Zyx.phs , MTcal.Zyx.rho , MTcal.Zyx.phs , 'yx' );

if ( MTobs.Nr == 8 )
hf4 = figure(8);  clf; set( hf4 , 'name' , 'Zyy');
plot_rhophs( MTobs.Zyy.rho , MTobs.Zyy.phs , MTcal.Zyy.rho , MTcal.Zyy.phs , 'yy' );
end
