function plot_rhophs( Robs , Pobs , Rcal , Pcal , Mode )
%%
%%  plot_rhophs( Robs , Pobs , Rcal , Pcal , Mode )
%%
%%  PLOT Observed / Calculated app-resistivity & phase
%%
%%       Output an 2x2 subfigure
%%                   [ RhoApp_obs  Phase_obs ]
%%                   [ RhoApp_cal  Phase_cal ]
%%    x-axis is Station ID
%%    y-axis is Period  ID (reversed: 1st < 2nd < .. < last period )
%%
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%

%% Load Colormap
colormap( getHSV );

% labels
xlab = 'station no.';
ylab = 'period no.';

% titles
tt.obs.r = strcat('RhoApp_{' , Mode , '} : Observed');
tt.obs.p = strcat( 'Phase_{' , Mode , '} : Observed');
tt.cal.r = strcat('RhoApp_{' , Mode , '} : Calculated');
tt.cal.p = strcat( 'Phase_{' , Mode , '} : Calculated');

% min/max
Rmax = max( [ Robs(:) ; Rcal(:) ] );
Rmin = min( [ Robs(:) ; Rcal(:) ] );
Pmax = max( [ Pobs(:) ; Pcal(:) ] );
Pmin = min( [ Pobs(:) ; Pcal(:) ] );

set(gcf,'Renderer','opengl')

%% Real-Z - Obs
subplot(2,2,1); 
imagesc( Robs(:,:) ); grid on
%%xlabel( xlab ); 
ylabel( ylab ); 
title( tt.obs.r );
caxis( [ Rmin Rmax ] ); colorbar;


%% Imag-Z - Obs
subplot(2,2,2);
imagesc( Pobs(:,:) ); grid on
%%xlabel( xlab ); 
%%ylabel( ylab ); 
title( tt.obs.p );
caxis( [ Pmin Pmax ] ); colorbar;


%% Real-Z - Cal
subplot(2,2,3);
imagesc( Rcal(:,:) ); grid on
xlabel( xlab ); 
ylabel( ylab ); 
title( tt.cal.r );
caxis( [ Rmin Rmax ] ); colorbar;


%% Imag-Z - Cal
subplot(2,2,4);
imagesc( Pcal(:,:) ); grid on
xlabel( xlab ); 
%%ylabel( ylab ); 
title( tt.cal.p );
caxis( [ Pmin Pmax ] ); colorbar;
