function [ MTdata ] = read_data(cfile)
%%
%%  [ MTdata ] = read_data(cfile);
%%    MTdata: Structure that contains
%%            Zij.r:  Real part of the Z's
%%            Zij.i: Image part of the Z's
%%            %%  [ Zxx Zxy ]
%%            %%  [ Zyx Zyy ]
%%
%%            per: periods
%%
%%            Ns: number of sites
%%            Np: number of periods
%%            Nr: number of record (4 or 8 or 12)
%%                Nr= 4: Zxy+Zyx, Tzx+Tzy
%%                Nr= 8: Zxx+Zxy+Zyx+Zyy, Zxy+Zyx+Tzx+Tzy
%%                Nr=12: Zxx+Zxy+Zyx+Zyy+Tzx+Tzy
%%
%%            Loc.east:  East position of the MT sites
%%            Loc.north: North position of the MT sites
%%
%%  READ WS3Dinv INPUT/OUTPUT DATA FILE
%%
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%

%% example
%% cdata  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d.data';
%% cderr  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d.error';
%% cresp  = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\OLDRUNTEST\blk3d_resp.05';
%%

% init
MTdata = [];

% open file / exit if bad file
fid = fopen(cfile,'r'); if ( fid <0 ),disp([cfile ' not read!']);return;end

% start reading
dat = fscanf(fid,'%d',3); %% Dimensions
Ns = dat(1);
Np = dat(2);
Nr = dat(3);
ctmp = fgets(fid); 

ctmp = fgets(fid); %% Station_Location: N-S
dstx = fscanf(fid,'%f',Ns);
ctmp = fgets(fid); 

ctmp = fgets(fid);%% Station_Location: E-W
dsty = fscanf(fid,'%f',Ns);
ctmp = fgets(fid);

per = zeros(Np,1);
for ip = 1:Np
    ctmp = fgets(fid);%% DATA_Period:   0.1000E+00
    per( ip ) = str2double( ctmp(findstr(ctmp,':')+1:end) );
    data = fscanf(fid,'%f',[Nr Ns]);
    ctmp = fgets(fid);
    ZRes(ip,:,:) = data(:,:);
end
fclose(fid);

%% Output
MTdata.Ns = Ns;
MTdata.Np = Np;
MTdata.Nr = Nr;
MTdata.loc.east  = dsty;
MTdata.loc.north = dstx;

MTdata.per   = per;
MTdata.ZRes  = ZRes;





function [ rho , phs ] = convert( per , zr , zi )
%%
%% Convert for app.resistivity and phase now
%% Equatioin are : 
%%   Z = conj( complex( zr , zi ) )  %% because convention of WS
%%   rho = ( |Z|^2 )/( w mu ) with mu = 4 pi 1e-7, and w = 2 pi f = 2 pi / per
%%   phs = arg( z ) = atan( z.i / z.r )*180/pi [deg]
%%
    z = conj( complex( zr , zi ) ); 
    rho = ( abs( z ).^2 )./( ( 2 * pi ./ per ) * ( 2 * pi * 1e-7 ) );
    phs = angle( z )*180/pi;
