function [ MeshNorth , MeshEast , MeshDepth , ResModel ] = read_model( cmodel )
%%
%%  [ MeshNorth , MeshEast , MeshDepth , ResModel ] = read_model( cmodel );
%%
%%      MeshNorth: cell size in South-North
%%      MeshEast : cell size in West-East
%%      MeshDepth: cell size in depth
%%      ResModel : resistivity model : size(NNorth,NEast,NDepth)
%%
%%  READ WS3Dinv INPUT/OUTPUT MODEL FILE
%%
%%  Mesh size:
%%        MeshNorth: North - South
%%        MeshEast: West - East   
%%        DZ: Layer thickness
%% Resistivity model:
%%        ResModel ( North-South , West-East , Depth )
%%
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%

%% Example
%% cmodel = 'C:\PROJECTS\WSINV3DMT\examples\TEST3DMT\init3d2';

MeshNorth   = []; %% North - South
MeshEast    = []; %% West - East
MeshDepth   = []; %% Layers
ResModel    = []; %% Resistivity model

fid = fopen(cmodel,'r');if ( fid <0 ),disp([cmodel ' not read!']);return;end

ctmp = fgets(fid);
dtmp = fscanf(fid,'%d',4);

N.north = dtmp(1); 
N.east  = dtmp(2); 
N.depth = dtmp(3); 
N.read  = dtmp(4);

MeshNorth(N.north:-1:1) = fscanf(fid,'%f',N.north); MeshNorth = MeshNorth(:); %% North - South
MeshEast                = fscanf(fid,'%f',N.east ); MeshEast  = MeshEast(:); %%  West -  East
MeshDepth               = fscanf(fid,'%f',N.depth); MeshDepth = MeshDepth(:); %% Depth

ResModel = zeros( N.north , N.east , N.depth );
rmap     = zeros( N.north , N.east ); 

if ( N.read ~= 0 )
    RhoT = fscanf(fid,'%f',N.read);
    cok  = 0;% false
    while ( ~cok )
        izt = fscanf(fid,'%d',2);
        for ie=1:N.east         %% read from  West to East
            for in=N.north:-1:1  %% read from North to South
                imap = fscanf(fid,'%d',1);
                rmap( in , ie ) = RhoT( imap );
            end
        end
        for iz = izt(1):izt(2)
            ResModel(:,:,iz) = rmap;
        end
        if (izt(2) >= N.depth )
            cok = 1; % true
        end
    end
    
else
    for iz = 1:N.depth              %% read 1st Layer to Last layer
        for ie = 1:N.east           %% read from  West to East
            for in = N.north:-1:1   %% read from North to South (so reverse)
                ResModel(in,ie,iz) = fscanf(fid,'%f',1);
            end
        end
    end
end

fclose(fid);
