function [ varargout ] = script_wsinv3d( varargin )
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 
%% RESULTS.title    : PROJECT TITLE
%% RESULTS.root     : CURRENT DIRECTORY/ STARTING POINT
%%
%% 
%% RESULTS.run.root : DIRECTORY OF RESULTS
%% RESULTS.run.data : SURVEY DATA
%% RESULTS.run.title: TITLE
%% 
%%
%% B.Tournerie  Quantec Geoscience Ltd
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

varargout = { -1 };
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ~isequal(nargin,1),varargout = { -1 };return;end

if ~isstruct( varargin{ 1 } ) & ...
        isfield( varargin{ 1 } ,'title')  & ...
        isfield( varargin{ 1 } ,'root')  & ...
        isfield( varargin{ 1 } ,'run')
    varargout = { -1 };
    return
end
RESULTS = varargin{ 1 };
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FWD DATA
%% if strcmp( questdlg('Show Raw data?', '', 'Yes', 'No', 'No') , 'Yes')
%%    ROOT   = [ RESULTS.root '\' RESULTS.run.root '\' RESULTS.run.data ];
%%    cdata  = [ ROOT '_out.data' ];
%%    cresp  = [ ROOT '_out_resp.00' ];
%%    plot_obscal( cdata , cresp )
%% end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% INV3D 
ROOT   = [ RESULTS.root '\' RESULTS.run.root '\' RESULTS.run.data ];
Miter = [];
for it=0:99
    iter = it;
    citer  = sprintf('%02d',iter);

    cdata  = [ ROOT '_out.data' ];
    cderr  = [ ROOT '_out.error' ];
    cresp  = [ ROOT '_out_resp.'  citer];
    cmodel = [ ROOT '_out_model.' citer];
    
    rms=[];
    if isfileok(cresp), 
        rms = calcul_rms( cdata , cderr , cresp );
        if ~isempty(rms{1}), 
            fprintf(' current RMS[%2d]= %f\n',  iter, rms{1} );
            Miter = [ Miter iter rms{1} ];
            
            figure(10+it);
            Zm = rms{2};
            Xm = rms{3}.east( :);dx = ( max(Xm) - min(Xm) )/500;
            Ym = rms{3}.north(:);dy = ( max(Ym) - min(Ym) )/500;
            [XI,YI] = meshgrid( min(Xm):dx:max(Xm) , min(Ym):dy:max(Ym) );
            [ZI] = griddata(Xm,Ym,Zm,XI,YI,'nearest');
            [c,h]=contour(XI,YI,ZI); clabel(c,h);colorbar;hold on
            set(plot(Xm,Ym),...
                'Marker','o','MarkerSize',4,'MarkerEdgeColor','k',...
                'MarkerFaceColor','k','LineStyle','none');hold off
            set(gca , ...
                'Xlim' , [min(Xm)-10*dx max(Xm)+10*dx] , ...
                'Ylim' , [min(Ym)-10*dx max(Ym)+10*dx] , 'DataAspectRatio', [1 1 1] );
            grid on
            eval( [ 'print -dpng ' RESULTS.run.root '_rms' citer '.png' ] )
            
            exportWS2UBC( cmodel );
         end
    else
        break;
    end
end

Miter = reshape( Miter , 2 , length(Miter)/2 )';
hf=figure;plot( Miter(:,1) , Miter(:,2) , 'bo-' );
xlabel(' iter#'); ylabel('rms');
title( RESULTS.run.title );
set(gca, 'ylim' , [ 0  ceil(max(Miter(:,2))) ] );
grid on
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
uiwait(msgbox('Select ITER to convert to UBC; Stop with right click!','WS3D2UBC','help'));
ok=0; Kiter = [];
while ~isequal(ok,1)
    [a,b,c] = ginput(1);
    if ~isequal(c,1), ok=1;
    else, Kiter = [ Kiter round(a) ];
    hold on           %% +1 because ID=1 is iter 0
    plot( Miter( round(a)+1 , 1 ) , Miter(round(a)+1 , 2 ) , 'k*' );
    hold off
    end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
eval( [ 'print -dpng ' RESULTS.run.root '_rms.png' ] )
%%close(hf);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


fout = strcat( ROOT,'_remesh.bat' );
fid  = fopen( fout ,'w');
if fid < 0, disp(['File ',fout,' not open']);varargout = { -1 }; return;end
for k=1:length(Kiter)
citer = Kiter(k);
cmesh1 = [ RESULTS.run.data '_out_model_' sprintf('%02d',citer) '_ubc.msh ' ];
cmesh2 = [ RESULTS.run.data '_ubc.msh ' ];
cmodel1= [ RESULTS.run.data '_out_model_' sprintf('%02d',citer) '_ubc.con ' ];
cmodel2= [ RESULTS.run.data '_' sprintf('%02d',citer) '.con' ];
fprintf( fid , '\n%s\n' , [ 'remesh3d.exe ' cmesh1  cmesh2 cmodel1  cmodel2 ] ); 
end
fclose(  fid );
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

varargout = { 1 };
return


citer = Kiter(1);
cdata  = [ ROOT '_out.data' ];
cmodel = [ ROOT '_out_model.' sprintf('%02d',citer) ];


plot_model( cmodel ,  cdata )



